@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.91.92"
+version     = "2.91.93"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/aleiva/work/gnome/orca-master/bld"
+prefix      = "/home/jd/orca/bld"
 
 # The package name (should be "orca").
 #
